# Calories tracker Nutritional information

All information used to elaborate this app has been taken from Internet Open Sources

This app hasn't medical recomendations. You should ask to nutrition experts to modifie you alimentation habits.

